@@ -4,7 +4,7 @@
     *
     */
 
-   global $usernameMotdWelcomeMessage;
+   global $usernameMotdWelcomeMessage, $add_domain_to_username;
 
 
    //===========================================================
@@ -18,6 +18,11 @@
    $usernameMotdWelcomeMessage = 'Welcome, <font color="red">###USERNAME###</font>!';
 
 
+   // Do you want to display "@domain.com" after the username?
+   // If so, set this to 1, otherwise, set it to zero.
+   //
+   $add_domain_to_username = 0;
+
    //===========================================================
 
 
@@ -50,7 +55,7 @@
 
 
    function username_show() {
-      global $color, $username, $show_username;
+      global $color, $username, $show_username, $domain, $add_domain_to_username;
       
       if (! $show_username)
          return;
@@ -64,6 +69,8 @@
           echo $username;
       if ($show_username == 2)
           echo _("Logged in as:") . ' ' . $username;
+      if ($add_domain_to_username)
+          echo '@' . $domain;
        
 ?></small>
 </td></tr></table>
@@ -75,16 +82,22 @@
 
    function username_show_motd_do() {
 
-      global $motd, $username, $usernameMotdWelcomeMessage;
+      global $motd, $username, $username_motd, $domain,
+             $add_domain_to_username, $usernameMotdWelcomeMessage;
 
-      $motd = str_replace('###USERNAME###', $username, $usernameMotdWelcomeMessage);
+      if ($username_motd)
+         $motd = str_replace('###USERNAME###', 
+                             ($add_domain_to_username ? 
+                                 $username . '@' . $domain : 
+                                 $username), 
+                             $usernameMotdWelcomeMessage);
 
    }
 
 
    function username_show_options_do() {
       global $show_username, $show_username_pos, $username_motd, 
-             $username, $data_dir;
+             $username, $data_dir, $domain, $add_domain_to_username;
       ?>
          <tr>
             <td align=right>Show Username:</td>
@@ -98,12 +111,18 @@
 
 	          if ($show_username == 1)
 		     $sel = ' selected';
-		  echo "<option value=1$sel>$username\n";
+		  echo "<option value=1$sel>$username";
+                  if ($add_domain_to_username)
+                      echo '@' . $domain;
+                  echo "\n";
 		  $sel = '';
 
 	          if ($show_username == 2)
 		     $sel = ' selected';
-		  echo "<option value=2$sel>" . _("Logged in as:") . "  $username\n";
+		  echo "<option value=2$sel>" . _("Logged in as:") . "  $username";
+                  if ($add_domain_to_username)
+                      echo '@' . $domain;
+                  echo "\n";
 		  $sel = '';
                ?>
                </select>
@@ -161,11 +180,12 @@
 
    function username_load_options_do() {
       global $username_motd, $show_username, $show_username_pos, 
-             $username, $data_dir;
+             $username, $data_dir, $add_domain_to_username;
 
       $show_username = getPref($data_dir, $username, 'show_username');
       $show_username_pos = getPref($data_dir, $username, 'show_username_pos');
       $username_motd = getPref($data_dir, $username, 'username_motd', 0);
+      //$add_domain_to_username = getPref($data_dir, $username, 'add_domain_to_username', 0);
    }
 
 
